summaryrefslogtreecommitdiff
path: root/include/llvm/Support/SystemUtils.h
diff options
context:
space:
mode:
authorGabor Greif <ggreif@gmail.com>2007-07-05 17:07:56 +0000
committerGabor Greif <ggreif@gmail.com>2007-07-05 17:07:56 +0000
commita99be51bf5cdac1438069d4b01766c47704961c8 (patch)
treec743819ee5ce71fc3aa76ed445ca89201b4daf4a /include/llvm/Support/SystemUtils.h
parentf8ad9552215503f7573b5049567ed59c37cc9636 (diff)
downloadllvm-a99be51bf5cdac1438069d4b01766c47704961c8.tar.gz
llvm-a99be51bf5cdac1438069d4b01766c47704961c8.tar.bz2
llvm-a99be51bf5cdac1438069d4b01766c47704961c8.tar.xz
Here is the bulk of the sanitizing.
Almost all occurrences of "bytecode" in the sources have been eliminated. git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@37913 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include/llvm/Support/SystemUtils.h')
-rw-r--r--include/llvm/Support/SystemUtils.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/llvm/Support/SystemUtils.h b/include/llvm/Support/SystemUtils.h
index 93432b57bf..6dc5c2727b 100644
--- a/include/llvm/Support/SystemUtils.h
+++ b/include/llvm/Support/SystemUtils.h
@@ -21,10 +21,10 @@ namespace llvm {
/// Determine if the ostream provided is connected to the std::cout and
/// displayed or not (to a console window). If so, generate a warning message
/// advising against display of bytecode and return true. Otherwise just return
/// false
/// @brief Check for output written to a console
-bool CheckBytecodeOutputToConsole(
+bool CheckBitcodeOutputToConsole(
std::ostream* stream_to_check, ///< The stream to be checked
bool print_warning = true ///< Control whether warnings are printed
);
@@ -21,10 +21,10 @@ namespace llvm {
/// Determine if the ostream provided is connected to the std::cout and
/// displayed or not (to a console window). If so, generate a warning message
-/// advising against display of bytecode and return true. Otherwise just return
+/// advising against display of bitcode and return true. Otherwise just return
/// false
/// @brief Check for output written to a console